==> openshift-model-machine-5.12.0-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineHealthCheckSpecBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MachineHealthCheckSpecBuilder extends io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpecFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpec,io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpecBuilder>{
  public MachineHealthCheckSpecBuilder() {
    this(false);
  }
  public MachineHealthCheckSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new MachineHealthCheckSpec(), validationEnabled);
  }
  public MachineHealthCheckSpecBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineHealthCheckSpecBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MachineHealthCheckSpec(), validationEnabled);
  }
  public MachineHealthCheckSpecBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpecFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpec instance) {
    this(fluent, instance, false);
  }
  public MachineHealthCheckSpecBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpecFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMaxUnhealthy(instance.getMaxUnhealthy()); 
    fluent.withNodeStartupTimeout(instance.getNodeStartupTimeout()); 
    fluent.withRemediationTemplate(instance.getRemediationTemplate()); 
    fluent.withSelector(instance.getSelector()); 
    fluent.withUnhealthyConditions(instance.getUnhealthyConditions()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineHealthCheckSpecBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpec instance) {
    this(instance,false);
  }
  public MachineHealthCheckSpecBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMaxUnhealthy(instance.getMaxUnhealthy()); 
    this.withNodeStartupTimeout(instance.getNodeStartupTimeout()); 
    this.withRemediationTemplate(instance.getRemediationTemplate()); 
    this.withSelector(instance.getSelector()); 
    this.withUnhealthyConditions(instance.getUnhealthyConditions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckSpec build() {
    MachineHealthCheckSpec buildable = new MachineHealthCheckSpec(fluent.getMaxUnhealthy(),fluent.getNodeStartupTimeout(),fluent.getRemediationTemplate(),fluent.getSelector(),fluent.getUnhealthyConditions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachineHealthCheckSpecBuilder that = (MachineHealthCheckSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-machine-6.3.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineHealthCheckSpecBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineHealthCheckSpecBuilder extends MachineHealthCheckSpecFluentImpl<MachineHealthCheckSpecBuilder> implements VisitableBuilder<MachineHealthCheckSpec,MachineHealthCheckSpecBuilder>{
  public MachineHealthCheckSpecBuilder() {
    this(false);
  }
  public MachineHealthCheckSpecBuilder(Boolean validationEnabled) {
    this(new MachineHealthCheckSpec(), validationEnabled);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineHealthCheckSpec(), validationEnabled);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpecFluent<?> fluent,MachineHealthCheckSpec instance) {
    this(fluent, instance, false);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpecFluent<?> fluent,MachineHealthCheckSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMaxUnhealthy(instance.getMaxUnhealthy()); 
    fluent.withNodeStartupTimeout(instance.getNodeStartupTimeout()); 
    fluent.withRemediationTemplate(instance.getRemediationTemplate()); 
    fluent.withSelector(instance.getSelector()); 
    fluent.withUnhealthyConditions(instance.getUnhealthyConditions()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpec instance) {
    this(instance,false);
  }
  public MachineHealthCheckSpecBuilder(MachineHealthCheckSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withMaxUnhealthy(instance.getMaxUnhealthy()); 
    this.withNodeStartupTimeout(instance.getNodeStartupTimeout()); 
    this.withRemediationTemplate(instance.getRemediationTemplate()); 
    this.withSelector(instance.getSelector()); 
    this.withUnhealthyConditions(instance.getUnhealthyConditions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MachineHealthCheckSpecFluent<?> fluent;
  Boolean validationEnabled;
  public MachineHealthCheckSpec build() {
    MachineHealthCheckSpec buildable = new MachineHealthCheckSpec(fluent.getMaxUnhealthy(),fluent.getNodeStartupTimeout(),fluent.getRemediationTemplate(),fluent.getSelector(),fluent.getUnhealthyConditions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
